Dojo Spinner Widget Test

# Dijit Spinner Test

Try typing values, and use the up/down arrow keys and/or the arrow push buttons to spin

# number spinner

initial value=900, no delta specified, no min specified, max=1550, onChange captured, big font
Spinbox #1:
onChange:
initial value=1000, delta=10, min=9 max=1550
Spinbox with custom styling (width=50%, 200% Courier font):
Spinner line break test: initial value not specified, delta not specified, min not specified, max not specified, signed not specified, separator not specified
[verify no line break just after this text] [verify no line break just before this text]
Move the cursor left and right within the input field to see the effect on the spinner.
initial value=+1.0, smalldelta=0.1, largedelta=1.0, min=-10.9, max=155, places=1, maxLength=20, exponent=false
Real Number Spinbox #1:

Spinner with no maximum, 1 decimal place: